<?php
class Stay_connected extends plxPlugin {
	private $session_domain='';
	private $path_to_salt=PLX_PLUGINS.'Stay_connected/salt.php';
	private $cookies_path=PLX_PLUGINS.'Stay_connected/cookies_files/';
	private $cookie_name='';
	private $redirect='';

	public function __construct($default_lang) {
		# appel du constructeur de la classe plxPlugin (obligatoire)
		parent::__construct($default_lang);

		# limite l'accès à l'écran d'administration du plugin
		# PROFIL_ADMIN , PROFIL_MANAGER , PROFIL_MODERATOR , PROFIL_EDITOR , PROFIL_WRITER
		$this->setConfigProfil(PROFIL_ADMIN);
		
		# Déclaration d'un hook (existant ou nouveau)
		$this->addHook('AdminAuth','AdminAuth');
		$this->addHook('AdminAuthPrepend','AdminAuthPrepend');		
		// generation du fichier salt unique (pour sécuriser le cookie)
		$path_to_salt=PLX_PLUGINS.'Stay_connected/salt.php';
		if (!is_file($path_to_salt)){
			file_put_contents($path_to_salt,'<?php define("SALT_STAY_CONNECTED","'.$this->generateSalt(512).'");?>' );
		}
	}

	private function generateSalt($length=256){
		$salt='';
		for($i=1;$i<=$length;$i++){
			$salt.=chr(mt_rand(35,126));
		}
		return str_replace(['\\','"',"'"],'!',$salt);
	}
	private function isLogged(){
		return (
	        isset($_SESSION['user']) &&
	        isset($_SESSION['profil']) &&
	        isset($_SESSION['hash']) &&
	        isset($_SESSION['domain']) &&
	        isset($_SESSION['lang'])
	    );
	}

	# Activation / désactivation
	public function OnActivate() {
		
	}
	public function redirectUrl(){
		$plxAdmin=plxAdmin::getInstance();
		$redirect=$plxAdmin->aConf['racine'];

		if(!empty($_GET['p'])) {
			$redirect =urldecode($_GET['p']);
			$query = parse_url($redirect)['query'];// pas fini
		}
		return $redirect;
	}
	public function destroyCookie(){
		if (isset($_COOKIE[$this->getCookieName()])){
			setcookie($this->getCookieName(),'',time()-60);// Expiration forcée du cookie
			if (is_file($this->cookies_path.$_COOKIE[$this->getCookieName()])){
				unlink($this->cookies_path.$_COOKIE[$this->getCookieName()]);
			}
		}
	}
	public function createCookie(){
		if (!empty($_POST['stay_connected'])){
			include ($this->path_to_salt);
			# ici, on crée un token pour la génération du cookie
			$token_cookie=hash('sha512',SALT_STAY_CONNECTED.md5(preg_replace('#[^a-zA-Z]#','',uniqid(true))));
			setcookie($this->getCookieName(),$token_cookie,time()+31536000);// Expiration au bout d'un an
			file_put_contents($this->cookies_path.$token_cookie,$_SESSION["user"]);
		}
	}
	public function checkCookie($session_domain){
		$plxAdmin=plxAdmin::getInstance();
		if (isset($_COOKIE[$this->getCookieName()]) && is_file($this->cookies_path.$_COOKIE[$this->getCookieName()])){
			$user_nb=file_get_contents($this->cookies_path.$_COOKIE[$this->getCookieName()]);
			$connected = false;
			foreach($plxAdmin->aUsers as $userid => $user) {
				if ($user_nb==$userid AND $user["active"] AND !$user["delete"]) {
					$_SESSION["user"] = $userid;
					$_SESSION["profil"] = $user["profil"];
					$_SESSION["hash"] = plxUtils::charAleatoire(10);
					$_SESSION["domain"] = $session_domain;
					$_SESSION["lang"] = $user["lang"];
					$connected = true;
				}
			}
			if($connected){
				header("Location: ".htmlentities($this->getRedirectUrl()));
				exit;
			}
		}
	}
	public function getRedirectUrl(){
		if (empty($this->redirect)){
			$this->redirect=$this->redirectUrl();
		}
		return $this->redirect;
	}
	public function getCookieName(){
		if (empty($this->cookie_name)){
			$plxAdmin=plxAdmin::getInstance();
			$this->cookie_name=preg_replace('#[^a-zA-Z]#','',$plxAdmin->aConf["racine"]);
		}
		return $this->cookie_name;
	}
	# HOOKS

	# Ajout de la case rester connecté
	public function AdminAuth(){

		echo '
			<input type="checkbox" id="id_stay_connected" name="stay_connected" style="float:none;width:5%;vertical-align: middle;" value="yes"/>
			<label for="id_stay_connected" style="float:none;width:80%;display:inline-block;vertical-align: middle;" title="Ne cochez pas sur des ordinateurs publics !">
				Rester connecté
			</label>
			<hr style="height:1px;background:#ddd;border:none"/>

			
		';
	} 

	public function AdminAuthPrepend(){		
		$plxAdmin=plxAdmin::getInstance();
		$this->cookie_name=preg_replace('#[^a-zA-Z]#','',$plxAdmin->aConf["racine"]);
		
		#################################################
		# remplacement de la procédure d'identification #
		#################################################
		# Initialisation variable erreur
		$error = "";
		$msg = "";

		#########################################
		# Déconnexion (retait du cookie) #
		#########################################
		echo '<?php 
			if (empty($plxMotor)){ $plxMotor=plxMotor::getInstance();}
			$stay_connected=$plxMotor->plxPlugins->aPlugins["Stay_connected"];

			if(!empty($_GET["d"]) AND $_GET["d"]==1) {
				$stay_connected->destroyCookie();
			}


			$stay_connected->checkCookie($session_domain);
		 
		
			if(!empty($_POST["login"]) AND !empty($_POST["password"]) AND !empty($_POST["stay_connected"])) {
				$connected = false;
				foreach($plxAdmin->aUsers as $userid => $user) {
					if ($_POST["login"]==$user["login"] AND sha1($user["salt"].md5($_POST["password"]))===$user["password"] AND $user["active"] AND !$user["delete"]) {
						$_SESSION["user"] = $userid;
						$_SESSION["profil"] = $user["profil"];
						$_SESSION["hash"] = plxUtils::charAleatoire(10);
						$_SESSION["domain"] = $session_domain;
						$_SESSION["admin_lang"] = $user["lang"];
						$connected = true;
						break;
					}
				}
				if($connected) {
					# AJOUT: gestion de la case à cocher,
					# création du cookie (et du fichier user correspondant au token du cookie)
					$stay_connected->createCookie();
					header("Location: ".htmlentities($stay_connected->getRedirectUrl()));
					exit;
				} else {
					$msg = L_ERR_WRONG_PASSWORD;
					$error = "error";
				}
			}
	?>';
	}


}


?>
